package com.fs.qw.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.qw.domain.QwForbiddenWords;
import com.fs.qw.mapper.QwForbiddenWordsMapper;
import com.fs.qw.service.IQwForbiddenWordsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.List;


/**
 * 企微违禁词管理Service业务层处理
 *
 * @author fs
 * @date 2023-11-22
 */
@Service
public class QwForbiddenWordsServiceImpl implements IQwForbiddenWordsService
{
    @Autowired
    private QwForbiddenWordsMapper qwForbiddenWordsMapper;

    /**
     * 查询企微违禁词管理
     *
     * @param id 企微违禁词管理ID
     * @return 企微违禁词管理
     */
    @Override
    public QwForbiddenWords selectQwForbiddenWordsById(Long id)
    {
        return qwForbiddenWordsMapper.selectQwForbiddenWordsById(id);
    }

    /**
     * 查询企微违禁词管理列表
     *
     * @param qwForbiddenWords 企微违禁词管理
     * @return 企微违禁词管理
     */
    @Override
    public List<QwForbiddenWords> selectQwForbiddenWordsList(QwForbiddenWords qwForbiddenWords)
    {
        return qwForbiddenWordsMapper.selectQwForbiddenWordsList(qwForbiddenWords);
    }

    /**
     * 新增企微违禁词管理
     *
     * @param qwForbiddenWords 企微违禁词管理
     * @return 结果
     */
    @Override
    public int insertQwForbiddenWords(QwForbiddenWords qwForbiddenWords)
    {
        qwForbiddenWords.setCreateTime(DateUtils.getNowDate());
        return qwForbiddenWordsMapper.insertQwForbiddenWords(qwForbiddenWords);
    }

    /**
     * 修改企微违禁词管理
     *
     * @param qwForbiddenWords 企微违禁词管理
     * @return 结果
     */
    @Override
    public int updateQwForbiddenWords(QwForbiddenWords qwForbiddenWords)
    {
        qwForbiddenWords.setUpdateTime(DateUtils.getNowDate());
        return qwForbiddenWordsMapper.updateQwForbiddenWords(qwForbiddenWords);
    }

    /**
     * 批量删除企微违禁词管理
     *
     * @param ids 需要删除的企微违禁词管理ID
     * @return 结果
     */
    @Override
    public int deleteQwForbiddenWordsByIds(Long[] ids)
    {
        return qwForbiddenWordsMapper.deleteQwForbiddenWordsByIds(ids);
    }

    /**
     * 删除企微违禁词管理信息
     *
     * @param id 企微违禁词管理ID
     * @return 结果
     */
    @Override
    public int deleteQwForbiddenWordsById(Long id)
    {
        return qwForbiddenWordsMapper.deleteQwForbiddenWordsById(id);
    }

    @Override
    public List<QwForbiddenWords> QwForbiddenWordsList() {
        return qwForbiddenWordsMapper.QwForbiddenWordsList();
    }
}
